@@ -4,7 +4,7 @@
  * various token generation mediums. It also includes all of the
  * functions for retrieving, storing, and checking tokens.
  *
- * Copyright 1999-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 1999-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -23,7 +23,7 @@ class Horde_Token
      *
      * @return string  The generated id string.
      */
-    static public function generateId($seed = '')
+    public static function generateId($seed = '')
     {
         return Horde_Url::uriB64Encode(pack('H*', hash('sha1', uniqid(mt_rand()) . $seed . (isset($_SERVER['REMOTE_ADDR']) ? $_SERVER['REMOTE_ADDR'] : ''))));
     }
